@@ -22,17 +22,14 @@ def masks_and_traces(ops, stat_manual, stat_orig):
         returns: F (ROIs x time), Fneu (ROIs x time), F_chan2, Fneu_chan2, ops, stat
         F_chan2 and Fneu_chan2 will be empty if no second channel
     '''
-    if 'aspect' in ops:
-        dy, dx = int(ops['aspect'] * 10), 10
-    else:
-        d0 = ops['diameter']
-        dy, dx = (d0, d0) if isinstance(d0, int) else d0
+
     t0 = time.time()
     # Concatenate stat so a good neuropil function can be formed
     stat_all = stat_manual.copy()
     for n in range(len(stat_orig)):
         stat_all.append(stat_orig[n])
-    stat_all = roi_stats(stat_all, dy, dx, ops['Ly'], ops['Lx'])
+    
+    stat_all = roi_stats(stat_all, ops['Ly'], ops['Lx'], aspect=ops.get('aspect', None), diameter=ops['diameter'])
     cell_masks = [
         masks.create_cell_mask(stat, Ly=ops['Ly'], Lx=ops['Lx'], allow_overlap=ops['allow_overlap']) for stat in stat_all
     ]
@@ -48,9 +45,9 @@ def masks_and_traces(ops, stat_manual, stat_orig):
     )
     print('Masks made in %0.2f sec.' % (time.time() - t0))
 
-    F, Fneu, F_chan2, Fneu_chan2, ops = extract_traces_from_masks(ops, 
-                                                                  manual_cell_masks, 
-                                                                  manual_neuropil_masks)
+    F, Fneu, F_chan2, Fneu_chan2 = extract_traces_from_masks(ops, 
+                                                             manual_cell_masks, 
+                                                             manual_neuropil_masks)
 
     # compute activity statistics for classifier
     npix = np.array([stat_orig[n]['npix'] for n in range(len(stat_orig))]).astype('float32')
