@@ -147,7 +147,8 @@ def merge_activity_masks(parent):
 
     # add cell to structs
     parent.stat = np.concatenate((parent.stat, np.array([stat0])), axis=0)
-    parent.stat = roi_stats(parent.stat, d0[0], d0[1], parent.Ly, parent.Lx)
+    parent.stat =  roi_stats(parent.stat, parent.Ly, parent.Lx, aspect=parent.ops.get('aspect', None), 
+						     diameter=parent.ops.get('diameter', None), do_crop=parent.ops.get('soma_crop', 1))
     parent.stat[-1]['lam'] = parent.stat[-1]['lam'] * merged_cells.size
     parent.Fcell = np.concatenate((parent.Fcell, F[np.newaxis,:]), axis=0)
     parent.Fneu = np.concatenate((parent.Fneu, Fneu[np.newaxis,:]), axis=0)
