@@ -3,5 +3,5 @@ from .nwb import save_nwb, read_nwb, nwb_to_binary
 from .save import combined, compute_dydx, save_mat
 from .sbx import sbx_to_binary
 from .tiff import mesoscan_to_binary, ome_to_binary, tiff_to_binary, generate_tiff_filename, save_tiff
-from .binary import BinaryFile, BinaryFileCombined
+from .binary import BinaryFile, BinaryRWFile, BinaryFileCombined
 from .server import send_jobs
