@@ -8,8 +8,8 @@ from suite2p import classification
 
 def get_stat_iscell(data_dir_path):
     # stat with standard deviation and skew already calculated
-    stat = np.load(data_dir_path.joinpath('classification/pre_stat.npy'), allow_pickle=True)
-    expected_output = np.load(data_dir_path.joinpath('1plane1chan/suite2p/plane0/iscell.npy'))
+    stat = np.load(data_dir_path.joinpath('test_inputs/classification/pre_stat.npy'), allow_pickle=True)
+    expected_output = np.load(data_dir_path.joinpath('test_outputs/classification/expected_classify_output_1p1c0.npy'))
     return stat, expected_output
 
 
